@@ -23,7 +23,7 @@ package Net::FullAuto::ISets::Local::Chaining_is;
 
 
 our $VERSION='0.01';
-our $DISPLAY='FullAuto© Proxy Chaining & RESTful Access';
+our $DISPLAY='FullAuto Proxy Chaining & RESTful Access';
 our $CONNECT='secure';
 our $defaultInstanceType='t2.small';
 
